/****************************************************************************
** Meta object code from reading C++ file 'game.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kapman-17.08.3/game.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'game.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Game_t {
    QByteArrayData data[40];
    char stringdata0[398];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Game_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Game_t qt_meta_stringdata_Game = {
    {
QT_MOC_LITERAL(0, 0, 4), // "Game"
QT_MOC_LITERAL(1, 5, 11), // "gameStarted"
QT_MOC_LITERAL(2, 17, 0), // ""
QT_MOC_LITERAL(3, 18, 8), // "gameOver"
QT_MOC_LITERAL(4, 27, 8), // "p_unused"
QT_MOC_LITERAL(5, 36, 12), // "levelStarted"
QT_MOC_LITERAL(6, 49, 10), // "p_newLevel"
QT_MOC_LITERAL(7, 60, 12), // "pauseChanged"
QT_MOC_LITERAL(8, 73, 7), // "p_pause"
QT_MOC_LITERAL(9, 81, 10), // "p_fromUser"
QT_MOC_LITERAL(10, 92, 12), // "elementEaten"
QT_MOC_LITERAL(11, 105, 3), // "p_x"
QT_MOC_LITERAL(12, 109, 3), // "p_y"
QT_MOC_LITERAL(13, 113, 7), // "bonusOn"
QT_MOC_LITERAL(14, 121, 8), // "bonusOff"
QT_MOC_LITERAL(15, 130, 12), // "levelChanged"
QT_MOC_LITERAL(16, 143, 7), // "p_level"
QT_MOC_LITERAL(17, 151, 12), // "scoreChanged"
QT_MOC_LITERAL(18, 164, 7), // "p_score"
QT_MOC_LITERAL(19, 172, 12), // "livesChanged"
QT_MOC_LITERAL(20, 185, 7), // "p_lives"
QT_MOC_LITERAL(21, 193, 15), // "pointsToDisplay"
QT_MOC_LITERAL(22, 209, 11), // "p_wonPoints"
QT_MOC_LITERAL(23, 221, 6), // "p_xPos"
QT_MOC_LITERAL(24, 228, 6), // "p_yPos"
QT_MOC_LITERAL(25, 235, 13), // "keyPressEvent"
QT_MOC_LITERAL(26, 249, 10), // "QKeyEvent*"
QT_MOC_LITERAL(27, 260, 7), // "p_event"
QT_MOC_LITERAL(28, 268, 22), // "resumeAfterKapmanDeath"
QT_MOC_LITERAL(29, 291, 6), // "update"
QT_MOC_LITERAL(30, 298, 11), // "kapmanDeath"
QT_MOC_LITERAL(31, 310, 10), // "ghostDeath"
QT_MOC_LITERAL(32, 321, 6), // "Ghost*"
QT_MOC_LITERAL(33, 328, 7), // "p_ghost"
QT_MOC_LITERAL(34, 336, 9), // "winPoints"
QT_MOC_LITERAL(35, 346, 8), // "Element*"
QT_MOC_LITERAL(36, 355, 9), // "p_element"
QT_MOC_LITERAL(37, 365, 9), // "nextLevel"
QT_MOC_LITERAL(38, 375, 9), // "hideBonus"
QT_MOC_LITERAL(39, 385, 12) // "endPreyState"

    },
    "Game\0gameStarted\0\0gameOver\0p_unused\0"
    "levelStarted\0p_newLevel\0pauseChanged\0"
    "p_pause\0p_fromUser\0elementEaten\0p_x\0"
    "p_y\0bonusOn\0bonusOff\0levelChanged\0"
    "p_level\0scoreChanged\0p_score\0livesChanged\0"
    "p_lives\0pointsToDisplay\0p_wonPoints\0"
    "p_xPos\0p_yPos\0keyPressEvent\0QKeyEvent*\0"
    "p_event\0resumeAfterKapmanDeath\0update\0"
    "kapmanDeath\0ghostDeath\0Ghost*\0p_ghost\0"
    "winPoints\0Element*\0p_element\0nextLevel\0"
    "hideBonus\0endPreyState"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Game[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  114,    2, 0x06 /* Public */,
       3,    1,  115,    2, 0x06 /* Public */,
       5,    1,  118,    2, 0x06 /* Public */,
       7,    2,  121,    2, 0x06 /* Public */,
      10,    2,  126,    2, 0x06 /* Public */,
      13,    0,  131,    2, 0x06 /* Public */,
      14,    0,  132,    2, 0x06 /* Public */,
      15,    1,  133,    2, 0x06 /* Public */,
      17,    1,  136,    2, 0x06 /* Public */,
      19,    1,  139,    2, 0x06 /* Public */,
      21,    3,  142,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      25,    1,  149,    2, 0x0a /* Public */,
      28,    0,  152,    2, 0x0a /* Public */,
      29,    0,  153,    2, 0x08 /* Private */,
      30,    0,  154,    2, 0x08 /* Private */,
      31,    1,  155,    2, 0x08 /* Private */,
      34,    1,  158,    2, 0x08 /* Private */,
      37,    0,  161,    2, 0x08 /* Private */,
      38,    0,  162,    2, 0x08 /* Private */,
      39,    0,  163,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool,    8,    9,
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,   11,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,   16,
    QMetaType::Void, QMetaType::UInt,   18,
    QMetaType::Void, QMetaType::UInt,   20,
    QMetaType::Void, QMetaType::Long, QMetaType::QReal, QMetaType::QReal,   22,   23,   24,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 26,   27,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 32,   33,
    QMetaType::Void, 0x80000000 | 35,   36,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Game::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Game *_t = static_cast<Game *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->gameStarted(); break;
        case 1: _t->gameOver((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 2: _t->levelStarted((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 3: _t->pauseChanged((*reinterpret_cast< const bool(*)>(_a[1])),(*reinterpret_cast< const bool(*)>(_a[2]))); break;
        case 4: _t->elementEaten((*reinterpret_cast< const qreal(*)>(_a[1])),(*reinterpret_cast< const qreal(*)>(_a[2]))); break;
        case 5: _t->bonusOn(); break;
        case 6: _t->bonusOff(); break;
        case 7: _t->levelChanged((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 8: _t->scoreChanged((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 9: _t->livesChanged((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 10: _t->pointsToDisplay((*reinterpret_cast< long(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2])),(*reinterpret_cast< qreal(*)>(_a[3]))); break;
        case 11: _t->keyPressEvent((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 12: _t->resumeAfterKapmanDeath(); break;
        case 13: _t->update(); break;
        case 14: _t->kapmanDeath(); break;
        case 15: _t->ghostDeath((*reinterpret_cast< Ghost*(*)>(_a[1]))); break;
        case 16: _t->winPoints((*reinterpret_cast< Element*(*)>(_a[1]))); break;
        case 17: _t->nextLevel(); break;
        case 18: _t->hideBonus(); break;
        case 19: _t->endPreyState(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Ghost* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Element* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Game::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::gameStarted)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Game::*_t)(const bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::gameOver)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Game::*_t)(const bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::levelStarted)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Game::*_t)(const bool , const bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::pauseChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Game::*_t)(const qreal , const qreal );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::elementEaten)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Game::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::bonusOn)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Game::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::bonusOff)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (Game::*_t)(unsigned int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::levelChanged)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (Game::*_t)(unsigned int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::scoreChanged)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (Game::*_t)(unsigned int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::livesChanged)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (Game::*_t)(long , qreal , qreal );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Game::pointsToDisplay)) {
                *result = 10;
                return;
            }
        }
    }
}

const QMetaObject Game::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Game.data,
      qt_meta_data_Game,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Game::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Game::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Game.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Game::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void Game::gameStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Game::gameOver(const bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Game::levelStarted(const bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Game::pauseChanged(const bool _t1, const bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Game::elementEaten(const qreal _t1, const qreal _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Game::bonusOn()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Game::bonusOff()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Game::levelChanged(unsigned int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Game::scoreChanged(unsigned int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Game::livesChanged(unsigned int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Game::pointsToDisplay(long _t1, qreal _t2, qreal _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
