/****************************************************************************
** Meta object code from reading C++ file 'kapmanmainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kapman-17.08.3/kapmanmainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kapmanmainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KapmanMainWindow_t {
    QByteArrayData data[19];
    char stringdata0[210];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KapmanMainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KapmanMainWindow_t qt_meta_stringdata_KapmanMainWindow = {
    {
QT_MOC_LITERAL(0, 0, 16), // "KapmanMainWindow"
QT_MOC_LITERAL(1, 17, 8), // "initGame"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 7), // "newGame"
QT_MOC_LITERAL(4, 35, 10), // "p_gameOver"
QT_MOC_LITERAL(5, 46, 14), // "showHighscores"
QT_MOC_LITERAL(6, 61, 11), // "changeLevel"
QT_MOC_LITERAL(7, 73, 16), // "setSoundsEnabled"
QT_MOC_LITERAL(8, 90, 9), // "p_enabled"
QT_MOC_LITERAL(9, 100, 12), // "showSettings"
QT_MOC_LITERAL(10, 113, 12), // "loadSettings"
QT_MOC_LITERAL(11, 126, 5), // "close"
QT_MOC_LITERAL(12, 132, 12), // "displayLevel"
QT_MOC_LITERAL(13, 145, 7), // "p_level"
QT_MOC_LITERAL(14, 153, 12), // "displayScore"
QT_MOC_LITERAL(15, 166, 7), // "p_score"
QT_MOC_LITERAL(16, 174, 12), // "displayLives"
QT_MOC_LITERAL(17, 187, 7), // "p_lives"
QT_MOC_LITERAL(18, 195, 14) // "resetStatusBar"

    },
    "KapmanMainWindow\0initGame\0\0newGame\0"
    "p_gameOver\0showHighscores\0changeLevel\0"
    "setSoundsEnabled\0p_enabled\0showSettings\0"
    "loadSettings\0close\0displayLevel\0p_level\0"
    "displayScore\0p_score\0displayLives\0"
    "p_lives\0resetStatusBar"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KapmanMainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x08 /* Private */,
       3,    1,   80,    2, 0x08 /* Private */,
       3,    0,   83,    2, 0x28 /* Private | MethodCloned */,
       5,    0,   84,    2, 0x08 /* Private */,
       6,    0,   85,    2, 0x08 /* Private */,
       7,    1,   86,    2, 0x08 /* Private */,
       9,    0,   89,    2, 0x08 /* Private */,
      10,    0,   90,    2, 0x08 /* Private */,
      11,    0,   91,    2, 0x08 /* Private */,
      12,    1,   92,    2, 0x08 /* Private */,
      14,    1,   95,    2, 0x08 /* Private */,
      16,    1,   98,    2, 0x08 /* Private */,
      18,    0,  101,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,   13,
    QMetaType::Void, QMetaType::UInt,   15,
    QMetaType::Void, QMetaType::UInt,   17,
    QMetaType::Void,

       0        // eod
};

void KapmanMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KapmanMainWindow *_t = static_cast<KapmanMainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->initGame(); break;
        case 1: _t->newGame((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 2: _t->newGame(); break;
        case 3: _t->showHighscores(); break;
        case 4: _t->changeLevel(); break;
        case 5: _t->setSoundsEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->showSettings(); break;
        case 7: _t->loadSettings(); break;
        case 8: _t->close(); break;
        case 9: _t->displayLevel((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 10: _t->displayScore((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 11: _t->displayLives((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 12: _t->resetStatusBar(); break;
        default: ;
        }
    }
}

const QMetaObject KapmanMainWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KapmanMainWindow.data,
      qt_meta_data_KapmanMainWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KapmanMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KapmanMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KapmanMainWindow.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KapmanMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
