/****************************************************************************
** Meta object code from reading C++ file 'gamescene.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kapman-17.08.3/gamescene.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gamescene.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_GameScene_t {
    QByteArrayData data[20];
    char stringdata0[192];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_GameScene_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_GameScene_t qt_meta_stringdata_GameScene = {
    {
QT_MOC_LITERAL(0, 0, 9), // "GameScene"
QT_MOC_LITERAL(1, 10, 5), // "intro"
QT_MOC_LITERAL(2, 16, 0), // ""
QT_MOC_LITERAL(3, 17, 10), // "p_newLevel"
QT_MOC_LITERAL(4, 28, 5), // "start"
QT_MOC_LITERAL(5, 34, 9), // "setPaused"
QT_MOC_LITERAL(6, 44, 7), // "p_pause"
QT_MOC_LITERAL(7, 52, 10), // "p_fromUser"
QT_MOC_LITERAL(8, 63, 11), // "hideElement"
QT_MOC_LITERAL(9, 75, 3), // "p_x"
QT_MOC_LITERAL(10, 79, 3), // "p_y"
QT_MOC_LITERAL(11, 83, 12), // "displayBonus"
QT_MOC_LITERAL(12, 96, 9), // "hideBonus"
QT_MOC_LITERAL(13, 106, 13), // "displayPoints"
QT_MOC_LITERAL(14, 120, 11), // "p_wonPoints"
QT_MOC_LITERAL(15, 132, 6), // "p_xPos"
QT_MOC_LITERAL(16, 139, 6), // "p_yPos"
QT_MOC_LITERAL(17, 146, 10), // "hidePoints"
QT_MOC_LITERAL(18, 157, 12), // "updateSvgIds"
QT_MOC_LITERAL(19, 170, 21) // "updateThemeProperties"

    },
    "GameScene\0intro\0\0p_newLevel\0start\0"
    "setPaused\0p_pause\0p_fromUser\0hideElement\0"
    "p_x\0p_y\0displayBonus\0hideBonus\0"
    "displayPoints\0p_wonPoints\0p_xPos\0"
    "p_yPos\0hidePoints\0updateSvgIds\0"
    "updateThemeProperties"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_GameScene[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x08 /* Private */,
       4,    0,   67,    2, 0x08 /* Private */,
       5,    2,   68,    2, 0x08 /* Private */,
       8,    2,   73,    2, 0x08 /* Private */,
      11,    0,   78,    2, 0x08 /* Private */,
      12,    0,   79,    2, 0x08 /* Private */,
      13,    3,   80,    2, 0x08 /* Private */,
      17,    0,   87,    2, 0x08 /* Private */,
      18,    0,   88,    2, 0x08 /* Private */,
      19,    0,   89,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool,    6,    7,
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,    9,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Long, QMetaType::QReal, QMetaType::QReal,   14,   15,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void GameScene::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GameScene *_t = static_cast<GameScene *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->intro((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 1: _t->start(); break;
        case 2: _t->setPaused((*reinterpret_cast< const bool(*)>(_a[1])),(*reinterpret_cast< const bool(*)>(_a[2]))); break;
        case 3: _t->hideElement((*reinterpret_cast< const qreal(*)>(_a[1])),(*reinterpret_cast< const qreal(*)>(_a[2]))); break;
        case 4: _t->displayBonus(); break;
        case 5: _t->hideBonus(); break;
        case 6: _t->displayPoints((*reinterpret_cast< long(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2])),(*reinterpret_cast< qreal(*)>(_a[3]))); break;
        case 7: _t->hidePoints(); break;
        case 8: _t->updateSvgIds(); break;
        case 9: _t->updateThemeProperties(); break;
        default: ;
        }
    }
}

const QMetaObject GameScene::staticMetaObject = {
    { &QGraphicsScene::staticMetaObject, qt_meta_stringdata_GameScene.data,
      qt_meta_data_GameScene,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *GameScene::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GameScene::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_GameScene.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsScene::qt_metacast(_clname);
}

int GameScene::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
