/****************************************************************************
** Meta object code from reading C++ file 'kapmanitem.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kapman-17.08.3/kapmanitem.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kapmanitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KapmanItem_t {
    QByteArrayData data[17];
    char stringdata0[159];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KapmanItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KapmanItem_t qt_meta_stringdata_KapmanItem = {
    {
QT_MOC_LITERAL(0, 0, 10), // "KapmanItem"
QT_MOC_LITERAL(1, 11, 15), // "updateDirection"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 15), // "manageCollision"
QT_MOC_LITERAL(4, 44, 6), // "update"
QT_MOC_LITERAL(5, 51, 3), // "p_x"
QT_MOC_LITERAL(6, 55, 3), // "p_y"
QT_MOC_LITERAL(7, 59, 9), // "startAnim"
QT_MOC_LITERAL(8, 69, 9), // "pauseAnim"
QT_MOC_LITERAL(9, 79, 10), // "resumeAnim"
QT_MOC_LITERAL(10, 90, 8), // "stopAnim"
QT_MOC_LITERAL(11, 99, 8), // "setFrame"
QT_MOC_LITERAL(12, 108, 7), // "p_frame"
QT_MOC_LITERAL(13, 116, 13), // "startBlinking"
QT_MOC_LITERAL(14, 130, 5), // "blink"
QT_MOC_LITERAL(15, 136, 15), // "setRotationFlag"
QT_MOC_LITERAL(16, 152, 6) // "rotate"

    },
    "KapmanItem\0updateDirection\0\0manageCollision\0"
    "update\0p_x\0p_y\0startAnim\0pauseAnim\0"
    "resumeAnim\0stopAnim\0setFrame\0p_frame\0"
    "startBlinking\0blink\0setRotationFlag\0"
    "rotate"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KapmanItem[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x0a /* Public */,
       3,    0,   70,    2, 0x0a /* Public */,
       4,    2,   71,    2, 0x0a /* Public */,
       7,    0,   76,    2, 0x0a /* Public */,
       8,    0,   77,    2, 0x0a /* Public */,
       9,    0,   78,    2, 0x0a /* Public */,
      10,    0,   79,    2, 0x0a /* Public */,
      11,    1,   80,    2, 0x0a /* Public */,
      13,    0,   83,    2, 0x0a /* Public */,
      14,    0,   84,    2, 0x0a /* Public */,
      15,    1,   85,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,    5,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   16,

       0        // eod
};

void KapmanItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KapmanItem *_t = static_cast<KapmanItem *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updateDirection(); break;
        case 1: _t->manageCollision(); break;
        case 2: _t->update((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 3: _t->startAnim(); break;
        case 4: _t->pauseAnim(); break;
        case 5: _t->resumeAnim(); break;
        case 6: _t->stopAnim(); break;
        case 7: _t->setFrame((*reinterpret_cast< const int(*)>(_a[1]))); break;
        case 8: _t->startBlinking(); break;
        case 9: _t->blink(); break;
        case 10: _t->setRotationFlag((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KapmanItem::staticMetaObject = {
    { &CharacterItem::staticMetaObject, qt_meta_stringdata_KapmanItem.data,
      qt_meta_data_KapmanItem,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KapmanItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KapmanItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KapmanItem.stringdata0))
        return static_cast<void*>(this);
    return CharacterItem::qt_metacast(_clname);
}

int KapmanItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = CharacterItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
